==> Demo_CH32F103C8T6_ST7789V2_3-Line_Hardware_SPI.zip: Demo_CH32F103C8T6_ST7789V2_3-Line_Hardware_SPI/HARDWARE/LCD/lcd.h <==
/**********************************************************************
 * ֻѧϰʹãδɣκ;
 * ӲƬCH32F103C8T6,Ƶ72MHZ
 * ˵ST7789V 3ӲSPI
 
 ----------------------------------------------------
 |ǧһʾƼ޹˾                        |
 |˾վ:www.qytft.com                            |
 |Ավhttps://shop580133616.taobao.com        |
 |̻() :+86 0755-27908130                     |
 |ҵѯ:18823372746 (쾭 WXͬ)              |
 |ҵѯ:15989313508 (뾭 WXͬ)              |
 ----------------------------------------------------

 ----------------------------------------------------
 |˾ṩ֧֣κμ⻶ӭʱѧϰ    |
 |֧QQ:3597321058                             |
 |֧:qyxskj@126.com                       |
 |֧:13723763193ܹ WXͬţ               |
 |QQȺ:792027219                            |
 ----------------------------------------------------

 * ˵:
 ========================ԴŽ==========================================        
 |   LCDģ           Ƭ                                             |
 |     VCC      --->      3.3V      //Դ                                    |
 |     GND      --->      GND       //Դ                                  | 
 |====================ƼŽ======================================|
 |   LCDģ 			     Ƭ                                             |
 |     CS       --->      PA4       //ҺƬѡźţ͵ƽЧ        |
 |     RST      --->      PA1       //Һλźţ͵ƽЧ        |
 |     SCL      --->      PA5       //ҺSPIʱź                   |
 |     SDI      --->      PA7       //ҺSPIдź                 |
 |     SDO      --->      PA6       //ҺSPI߶ź                 |
 |     LED      --->      PA15      //Һźţ粻ƣ3.3V|
 ==============================================================================
 
 * :2020/5/13
 * 汾V1.0
 * ȨУؾ
 * Copyright(C) ǧһʾƼ޹˾ 2020-2035
 * All rights reserved
**********************************************************************/		
#ifndef __LCD_H
#define __LCD_H		
#include "debug.h" 
#include "stdlib.h"

//LCDҪ
typedef struct  
{										    
	u16 width;			//LCD 
	u16 height;			//LCD ߶
	u16 id;				  //LCD ID
	u8  dir;			  //ƣ01	
	u16	 wramcmd;		//ʼдgramָ
	u16  setxcmd;		//xָ
	u16  setycmd;		//yָ	
  u8   xoffset;   //xƫ  
  u8	 yoffset;	  //yƫ
}_lcd_dev; 	

//LCD
extern _lcd_dev lcddev;	//LCDҪ
/////////////////////////////////////û///////////////////////////////////	 
#define USE_HORIZONTAL  	 0//Һ˳ʱת 	0-0ת1-90ת2-180ת3-270ת

//////////////////////////////////////////////////////////////////////////////////	  
//LCDĳߴ
#define LCD_W 240
#define LCD_H 240

//TFTLCDҪõĺ		   
extern u16  POINT_COLOR;//ĬϺɫ    
extern u16  BACK_COLOR; //ɫ.ĬΪɫ

////////////////////////////////////////////////////////////////////
//-----------------LCD˿ڶ---------------- 
#define GPIO_TYPE  GPIOA  //GPIO
#define LED      15        //       PA15
#define LCD_CS   4       //Ƭѡ             PA4
#define LCD_RST  1       //λ             PA1


//ģܿƱûҲԽPWMڱ
#define	LCD_LED PAout(LED) //LCD    		 PA15
//ʹùٷ⺯еײ㣬ٶȽ½14֡ÿ룬˾Ƽ
//IOֱӲĴIOˢʿԴﵽ28֡ÿ룡 

//GPIOλߣ
#define	LCD_CS_SET  GPIO_TYPE->BSHR=1<<LCD_CS    //Ƭѡ˿  	PB11
#define	LCD_RST_SET	GPIO_TYPE->BSHR=1<<LCD_RST   //λ			  PB12

//GPIOλͣ							    
#define	LCD_CS_CLR  GPIO_TYPE->BCR=1<<LCD_CS     //Ƭѡ˿  	PB11
#define	LCD_RST_CLR	GPIO_TYPE->BCR=1<<LCD_RST    //λ			  PB12

//ɫ
#define WHITE       0xFFFF
#define BLACK      	0x0000	  
#define BLUE       	0x001F  
#define BRED        0XF81F
#define GRED 			 	0XFFE0
#define GBLUE			 	0X07FF
#define RED         0xF800
#define MAGENTA     0xF81F
#define GREEN       0x07E0
#define CYAN        0x7FFF
#define YELLOW      0xFFE0
#define BROWN 			0XBC40 //ɫ
#define BRRED 			0XFC07 //غɫ
#define GRAY  			0X8430 //ɫ
//GUIɫ

#define DARKBLUE      	 0X01CF	//ɫ
#define LIGHTBLUE      	 0X7D7C	//ǳɫ  
#define GRAYBLUE       	 0X5458 //ɫ
//ɫΪPANELɫ 
 
#define LIGHTGREEN     	0X841F //ǳɫ
#define LIGHTGRAY     0XEF5B //ǳɫ(PANNEL)
#define LGRAY 			 		0XC618 //ǳɫ(PANNEL),屳ɫ

#define LGRAYBLUE      	0XA651 //ǳɫ(мɫ)
#define LBBLUE          0X2B12 //ǳɫ(ѡĿķɫ)
	    															  
void LCD_Init(void);
void LCD_DisplayOn(void);
void LCD_DisplayOff(void);
void LCD_Clear(u16 Color);	 
void LCD_SetCursor(u16 Xpos, u16 Ypos);
void LCD_DrawPoint(u16 x,u16 y);//
u16  LCD_ReadPoint(u16 x,u16 y); //
void LCD_DrawLine(u16 x1, u16 y1, u16 x2, u16 y2);
void LCD_DrawRectangle(u16 x1, u16 y1, u16 x2, u16 y2);		   
void LCD_SetWindows(u16 xStar, u16 yStar,u16 xEnd,u16 yEnd);

u8 LCD_RD_DATA(void);//ȡLCD									    
void LCD_WriteReg(u8 LCD_Reg, u16 LCD_RegValue);
void LCD_WR_DATA(u8 data);
u8 LCD_ReadReg(u8 reg,u8 n);
void LCD_WriteRAM_Prepare(void);
void LCD_WriteRAM(u16 RGB_Code);
u16 LCD_ReadRAM(void);		   
u16 LCD_BGR2RGB(u16 c);
void LCD_SetParam(void);
void Lcd_WriteData_16Bit(u16 Data);
void LCD_direction(u8 direction );
u16 LCD_RD_ID(void);			  		 
#endif

==> Demo_CH32F103C8T6_ST7789V2_4-Line_Hardware_SPI.zip: Demo_CH32F103C8T6_ST7789V2_4-Line_Hardware_SPI/HARDWARE/LCD/lcd.h <==
/**********************************************************************
 * ֻѧϰʹãδɣκ;
 * ӲƬCH32F103C8T6,Ƶ72MHZ
 * ˵ST7789V 4ӲSPI
 
 ----------------------------------------------------
 |ǧһʾƼ޹˾                        |
 |˾վ:www.qytft.com                            |
 |Ավhttps://shop580133616.taobao.com        |
 |̻() :+86 0755-27908130                     |
 |ҵѯ:18823372746 (쾭 WXͬ)              |
 |ҵѯ:15989313508 (뾭 WXͬ)              |
 ----------------------------------------------------

 ----------------------------------------------------
 |˾ṩ֧֣κμ⻶ӭʱѧϰ    |
 |֧QQ:3597321058                             |
 |֧:qyxskj@126.com                       |
 |֧:13723763193ܹ WXͬţ               |
 |QQȺ:792027219                            |
 ----------------------------------------------------

 * ˵:
 ========================ԴŽ=======================================================        
 |   LCDģ           Ƭ                                                          |
 |     VCC      --->      3.3V      //Դ                                                 |
 |     GND      --->      GND       //Դ                                               |  
 |====================ƼŽ===================================================|
 |   LCDģ 			     Ƭ                                                          |
 |     CS       --->      PA4       //ҺƬѡźţ͵ƽЧ                     |
 |     RST      --->      PA1       //Һλźţ͵ƽЧ                     |
 |     RS       --->      PA10      //Һ/ݿźţ͵ƽߵƽݣ|
 |     SCL      --->      PA5       //ҺSPIʱź                                |
 |     SDI      --->      PA7       //ҺSPIдź                              |
 |     SDO      --->      PA6       //ҺSPI߶ź                              |
 |     LED      --->      PA15      //Һźţ粻ƣ3.3V             |
 ===========================================================================================
 
 * :2020/5/13
 * 汾V1.0
 * ȨУؾ
 * Copyright(C) ǧһʾƼ޹˾ 2020-2035
 * All rights reserved
**********************************************************************/		
#ifndef __LCD_H
#define __LCD_H		
#include "debug.h" 
#include "stdlib.h"

//LCDҪ
typedef struct  
{										    
	u16 width;			//LCD 
	u16 height;			//LCD ߶
	u16 id;				  //LCD ID
	u8  dir;			  //ƣ01	
	u16	 wramcmd;		//ʼдgramָ
	u16  setxcmd;		//xָ
	u16  setycmd;		//yָ	
  u8   xoffset;   //xƫ  
  u8	 yoffset;	  //yƫ
}_lcd_dev; 	

//LCD
extern _lcd_dev lcddev;	//LCDҪ
/////////////////////////////////////û///////////////////////////////////	 
#define USE_HORIZONTAL  	 0//Һ˳ʱת 	0-0ת1-90ת2-180ת3-270ת

//////////////////////////////////////////////////////////////////////////////////	  
//LCDĳߴ
#define LCD_W 240
#define LCD_H 240

//TFTLCDҪõĺ		   
extern u16  POINT_COLOR;//ĬϺɫ    
extern u16  BACK_COLOR; //ɫ.ĬΪɫ

////////////////////////////////////////////////////////////////////
//-----------------LCD˿ڶ---------------- 
#define GPIO_TYPE  GPIOA  //GPIO
#define LED      15        //       PA15
#define LCD_CS   4       //Ƭѡ             PA4
#define LCD_RST  1       //λ             PA1
#define LCD_RS   10       //Ĵ/ѡ PA0 

//ģܿƱûҲԽPWMڱ
#define	LCD_LED PAout(LED) //LCD    		 PA15
//ʹùٷ⺯еײ㣬ٶȽ½14֡ÿ룬˾Ƽ
//IOֱӲĴIOˢʿԴﵽ28֡ÿ룡 

//GPIOλߣ
#define	LCD_CS_SET  GPIO_TYPE->BSHR=1<<LCD_CS    //Ƭѡ˿  	
#define	LCD_RST_SET	GPIO_TYPE->BSHR=1<<LCD_RST   //λ	
#define	LCD_RS_SET	GPIO_TYPE->BSHR=1<<LCD_RS    ///  	  

//GPIOλͣ							    
#define	LCD_CS_CLR  GPIO_TYPE->BCR=1<<LCD_CS     //Ƭѡ˿  	
#define	LCD_RST_CLR	GPIO_TYPE->BCR=1<<LCD_RST    //λ			  
#define	LCD_RS_CLR	GPIO_TYPE->BCR=1<<LCD_RS     ///  	

//ɫ
#define WHITE       0xFFFF
#define BLACK      	0x0000	  
#define BLUE       	0x001F  
#define BRED        0XF81F
#define GRED 			 	0XFFE0
#define GBLUE			 	0X07FF
#define RED         0xF800
#define MAGENTA     0xF81F
#define GREEN       0x07E0
#define CYAN        0x7FFF
#define YELLOW      0xFFE0
#define BROWN 			0XBC40 //ɫ
#define BRRED 			0XFC07 //غɫ
#define GRAY  			0X8430 //ɫ
//GUIɫ

#define DARKBLUE      	 0X01CF	//ɫ
#define LIGHTBLUE      	 0X7D7C	//ǳɫ  
#define GRAYBLUE       	 0X5458 //ɫ
//ɫΪPANELɫ 
 
#define LIGHTGREEN     	0X841F //ǳɫ
#define LIGHTGRAY     0XEF5B //ǳɫ(PANNEL)
#define LGRAY 			 		0XC618 //ǳɫ(PANNEL),屳ɫ

#define LGRAYBLUE      	0XA651 //ǳɫ(мɫ)
#define LBBLUE          0X2B12 //ǳɫ(ѡĿķɫ)
	    															  
void LCD_Init(void);
void LCD_DisplayOn(void);
void LCD_DisplayOff(void);
void LCD_Clear(u16 Color);	 
void LCD_SetCursor(u16 Xpos, u16 Ypos);
void LCD_DrawPoint(u16 x,u16 y);//
u16  LCD_ReadPoint(u16 x,u16 y); //
void LCD_DrawLine(u16 x1, u16 y1, u16 x2, u16 y2);
void LCD_DrawRectangle(u16 x1, u16 y1, u16 x2, u16 y2);		   
void LCD_SetWindows(u16 xStar, u16 yStar,u16 xEnd,u16 yEnd);

u8 LCD_RD_DATA(void);//ȡLCD									    
void LCD_WriteReg(u8 LCD_Reg, u16 LCD_RegValue);
void LCD_WR_DATA(u8 data);
u8 LCD_ReadReg(u8 reg,u8 n);
void LCD_WriteRAM_Prepare(void);
void LCD_WriteRAM(u16 RGB_Code);
u16 LCD_ReadRAM(void);		   
u16 LCD_BGR2RGB(u16 c);
void LCD_SetParam(void);
void Lcd_WriteData_16Bit(u16 Data);
void LCD_direction(u8 direction );
u16 LCD_RD_ID(void);			  		 
#endif
